@@ -558,6 +558,7 @@ class DataTransform(forms.ModelForm):
                                                                      can_delete_extra=True
                                                                      )
                 self.nested_data_transformer_form = dataTransformerInlineFormset(
+                    instance=self.instance,
                     queryset=self.instance.get_children(),
                     data=self.data if self.is_bound else None,
                     files=self.files if self.is_bound else None,
@@ -575,10 +576,11 @@ class DataTransform(forms.ModelForm):
                     files=self.files if self.is_bound else None
                 )
 
-        except Exception:
-            print('excpt')
+        except Exception as e:
+            print(str(e.with_traceback()))
 
         self.nested_constants_form = DataConstantsTransformerInlineFormset(
+            instance=self.instance,
             queryset=self.instance.datatransformerconstants_set,
             data=self.data if self.is_bound else None,
             files=self.files if self.is_bound else None,
@@ -587,6 +589,7 @@ class DataTransform(forms.ModelForm):
         )
 
         self.nested_hardware_outputs_form = HardwareTransformerInlineFormset(
+            instance=self.instance,
             queryset=self.instance.hardwaredatatransformer_set,
             data=self.data if self.is_bound else None,
             files=self.files if self.is_bound else None,
@@ -595,6 +598,7 @@ class DataTransform(forms.ModelForm):
         )
 
         self.nested_hardware_stats_form = HardwareStatsTransformerInlineFormset(
+            instance=self.instance,
             queryset=self.instance.hardwarestatsdatatransformer_set,
             data=self.data if self.is_bound else None,
             files=self.files if self.is_bound else None,
@@ -719,7 +723,7 @@ class DataTransformRoot(forms.ModelForm):
 
         self.nested_constants_form = DataConstantsTransformerInlineFormset(
             instance=self.instance,
-            queryset=self.instance.get_children(),
+            queryset=self.instance.datatransformerconstants_set,
             data=self.data if self.is_bound else None,
             files=self.files if self.is_bound else None,
             initial=[{'data_transformer': self.instance, 'id': str(uuid.uuid4())}]
@@ -728,7 +732,7 @@ class DataTransformRoot(forms.ModelForm):
 
         self.nested_hardware_outputs_form = HardwareTransformerInlineFormset(
             instance=self.instance,
-            queryset=self.instance.get_children(),
+            queryset=self.instance.hardwaredatatransformer_set,
             data=self.data if self.is_bound else None,
             files=self.files if self.is_bound else None,
             initial=[{'data_transformer': self.instance, 'id': str(uuid.uuid4())}]
@@ -737,7 +741,7 @@ class DataTransformRoot(forms.ModelForm):
 
         self.nested_hardware_stats_form = HardwareStatsTransformerInlineFormset(
             instance=self.instance,
-            queryset=self.instance.get_children(),
+            queryset=self.instance.hardwarestatsdatatransformer_set,
             data=self.data if self.is_bound else None,
             files=self.files if self.is_bound else None,
             initial=[{'data_transformer': self.instance, 'id': str(uuid.uuid4())}]
